# PyRocketSim

High-performance rocket trajectory simulation with Python bindings via pybind11.


### PyPI installation

```bash
pip install PyRocketSim
```

### **Requires Linux**:

- C++17 compiler
- CMake ≥ 3.18
- Python ≥ 3.7

### **Requires Windows**:

- Visual Studio C++

### License
MIT - See LICENSE for details